kedro.config — Kedro 0.17.6 documentation

# kedro.config

Description

`kedro.config` provides functionality for loading Kedro configuration from different file formats.

Classes

`kedro.config.ConfigLoader`(conf_paths) | Recursively scan the directories specified in `conf_paths` for configuration files with a `yaml`, `yml`, `json`, `ini`, `pickle`, `xml` or `properties` extension, load them, and return them in the form of a config dictionary.
`kedro.config.TemplatedConfigLoader`(conf_paths, *) | Extension of the `ConfigLoader` class that allows for template values, wrapped in brackets like: ${…}, to be automatically formatted based on the configs.

Exceptions

`kedro.config.MissingConfigException` | Raised when no configuration files can be found within a config path